@@ -19,6 +19,7 @@ import datetime
 import decimal
 import math
 import re
+from typing import Union
 
 from google.cloud._helpers import UTC
 from google.cloud._helpers import _date_from_iso8601_date
@@ -338,14 +339,15 @@ def _int_to_json(value):
     return value
 
 
-def _float_to_json(value):
+def _float_to_json(value) -> Union[None, str, float]:
     """Coerce 'value' to an JSON-compatible representation."""
     if value is None:
         return None
-    elif math.isnan(value) or math.isinf(value):
-        return str(value)
-    else:
-        return float(value)
+
+    if isinstance(value, str):
+        value = float(value)
+
+    return str(value) if (math.isnan(value) or math.isinf(value)) else float(value)
 
 
 def _decimal_to_json(value):
