@@ -21,6 +21,21 @@ from google.protobuf import json_format
 import google.cloud._helpers
 from google.cloud.bigquery import _helpers
 import google.cloud.bigquery_v2.types
+from google.cloud.bigquery_v2.types import StandardSqlTableType
+
+
+class RoutineType:
+    """The fine-grained type of the routine.
+
+    https://cloud.google.com/bigquery/docs/reference/rest/v2/routines#routinetype
+
+    .. versionadded:: 2.22.0
+    """
+
+    ROUTINE_TYPE_UNSPECIFIED = "ROUTINE_TYPE_UNSPECIFIED"
+    SCALAR_FUNCTION = "SCALAR_FUNCTION"
+    PROCEDURE = "PROCEDURE"
+    TABLE_VALUED_FUNCTION = "TABLE_VALUED_FUNCTION"
 
 
 class Routine(object):
@@ -48,6 +63,7 @@ class Routine(object):
         "modified": "lastModifiedTime",
         "reference": "routineReference",
         "return_type": "returnType",
+        "return_table_type": "returnTableType",
         "type_": "routineType",
         "description": "description",
         "determinism_level": "determinismLevel",
@@ -204,6 +220,35 @@ class Routine(object):
             resource = None
         self._properties[self._PROPERTY_TO_API_FIELD["return_type"]] = resource
 
+    @property
+    def return_table_type(self) -> StandardSqlTableType:
+        """The return type of a Table Valued Function (TVF) routine.
+
+        .. versionadded:: 2.22.0
+        """
+        resource = self._properties.get(
+            self._PROPERTY_TO_API_FIELD["return_table_type"]
+        )
+        if not resource:
+            return resource
+
+        output = google.cloud.bigquery_v2.types.StandardSqlTableType()
+        raw_protobuf = json_format.ParseDict(
+            resource, output._pb, ignore_unknown_fields=True
+        )
+        return type(output).wrap(raw_protobuf)
+
+    @return_table_type.setter
+    def return_table_type(self, value):
+        if not value:
+            resource = None
+        else:
+            resource = {
+                "columns": [json_format.MessageToDict(col._pb) for col in value.columns]
+            }
+
+        self._properties[self._PROPERTY_TO_API_FIELD["return_table_type"]] = resource
+
     @property
     def imported_libraries(self):
         """List[str]: The path of the imported JavaScript libraries.
