@@ -15,6 +15,7 @@
 """Schemas for BigQuery tables / queries."""
 
 import collections
+from typing import Optional
 
 from google.cloud.bigquery_v2 import types
 
@@ -105,7 +106,26 @@ class SchemaField(object):
         if max_length is not _DEFAULT_VALUE:
             self._properties["maxLength"] = max_length
         self._fields = tuple(fields)
-        self._policy_tags = policy_tags
+
+        self._policy_tags = self._determine_policy_tags(field_type, policy_tags)
+
+    @staticmethod
+    def _determine_policy_tags(
+        field_type: str, given_policy_tags: Optional["PolicyTagList"]
+    ) -> Optional["PolicyTagList"]:
+        """Return the given policy tags, or their suitable representation if `None`.
+
+        Args:
+            field_type: The type of the schema field.
+            given_policy_tags: The policy tags to maybe ajdust.
+        """
+        if given_policy_tags is not None:
+            return given_policy_tags
+
+        if field_type is not None and field_type.upper() in _STRUCT_TYPES:
+            return None
+
+        return PolicyTagList()
 
     @staticmethod
     def __get_int(api_repr, name):
@@ -126,18 +146,24 @@ class SchemaField(object):
         Returns:
             google.cloud.biquery.schema.SchemaField: The ``SchemaField`` object.
         """
+        field_type = api_repr["type"].upper()
+
         # Handle optional properties with default values
         mode = api_repr.get("mode", "NULLABLE")
         description = api_repr.get("description", _DEFAULT_VALUE)
         fields = api_repr.get("fields", ())
 
+        policy_tags = cls._determine_policy_tags(
+            field_type, PolicyTagList.from_api_repr(api_repr.get("policyTags"))
+        )
+
         return cls(
-            field_type=api_repr["type"].upper(),
+            field_type=field_type,
             fields=[cls.from_api_repr(f) for f in fields],
             mode=mode.upper(),
             description=description,
             name=api_repr["name"],
-            policy_tags=PolicyTagList.from_api_repr(api_repr.get("policyTags")),
+            policy_tags=policy_tags,
             precision=cls.__get_int(api_repr, "precision"),
             scale=cls.__get_int(api_repr, "scale"),
             max_length=cls.__get_int(api_repr, "maxLength"),
@@ -218,9 +244,9 @@ class SchemaField(object):
         # add this to the serialized representation.
         if self.field_type.upper() in _STRUCT_TYPES:
             answer["fields"] = [f.to_api_repr() for f in self.fields]
-
-        # If this contains a policy tag definition, include that as well:
-        if self.policy_tags is not None:
+        else:
+            # Explicitly include policy tag definition (we must not do it for RECORD
+            # fields, because those are not leaf fields).
             answer["policyTags"] = self.policy_tags.to_api_repr()
 
         # Done; return the serialized dictionary.
@@ -244,6 +270,11 @@ class SchemaField(object):
                     field_type = f"{field_type}({self.precision}, {self.scale})"
                 else:
                     field_type = f"{field_type}({self.precision})"
+
+        policy_tags = (
+            () if self._policy_tags is None else tuple(sorted(self._policy_tags.names))
+        )
+
         return (
             self.name,
             field_type,
@@ -251,7 +282,7 @@ class SchemaField(object):
             self.mode.upper(),  # pytype: disable=attribute-error
             self.description,
             self._fields,
-            self._policy_tags,
+            policy_tags,
         )
 
     def to_standard_sql(self) -> types.StandardSqlField:
