@@ -26,6 +26,7 @@ from .types.model_reference import ModelReference
 from .types.standard_sql import StandardSqlDataType
 from .types.standard_sql import StandardSqlField
 from .types.standard_sql import StandardSqlStructType
+from .types.standard_sql import StandardSqlTableType
 from .types.table_reference import TableReference
 
 __all__ = (
@@ -40,5 +41,6 @@ __all__ = (
     "StandardSqlDataType",
     "StandardSqlField",
     "StandardSqlStructType",
+    "StandardSqlTableType",
     "TableReference",
 )
