@@ -1,20 +1,22 @@
 # Copyright 2021 Google LLC
-
+#
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-
+#
 #     https://www.apache.org/licenses/LICENSE-2.0
-
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from .helpers import make_connection, dataset_polymorphic
 import pytest
 
+from google.cloud.bigquery.retry import DEFAULT_TIMEOUT
+from .helpers import make_connection, dataset_polymorphic
+
 
 def test_list_routines_empty_w_timeout(client):
     conn = client._connection = make_connection({})
@@ -85,7 +87,7 @@ def test_list_routines_defaults(
     assert actual_token == token
 
     conn.api_request.assert_called_once_with(
-        method="GET", path=path, query_params=query, timeout=None
+        method="GET", path=path, query_params=query, timeout=DEFAULT_TIMEOUT
     )
 
 
