@@ -12,6 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from collections import OrderedDict
 import inspect
 
 import pytest
@@ -32,12 +33,30 @@ def row_iterator_class():
 
 
 def test_to_arrow_method_signatures_match(query_job_class, row_iterator_class):
-    sig = inspect.signature(query_job_class.to_arrow)
-    sig2 = inspect.signature(row_iterator_class.to_arrow)
-    assert sig == sig2
+    query_job_sig = inspect.signature(query_job_class.to_arrow)
+    iterator_sig = inspect.signature(row_iterator_class.to_arrow)
+
+    assert "max_results" in query_job_sig.parameters
+
+    # Compare the signatures while ignoring the max_results parameter, which is
+    # specific to the method on QueryJob.
+    params = OrderedDict(query_job_sig.parameters)
+    del params["max_results"]
+    query_job_sig = query_job_sig.replace(parameters=params.values())
+
+    assert query_job_sig == iterator_sig
 
 
 def test_to_dataframe_method_signatures_match(query_job_class, row_iterator_class):
-    sig = inspect.signature(query_job_class.to_dataframe)
-    sig2 = inspect.signature(row_iterator_class.to_dataframe)
-    assert sig == sig2
+    query_job_sig = inspect.signature(query_job_class.to_dataframe)
+    iterator_sig = inspect.signature(row_iterator_class.to_dataframe)
+
+    assert "max_results" in query_job_sig.parameters
+
+    # Compare the signatures while ignoring the max_results parameter, which is
+    # specific to the method on QueryJob.
+    params = OrderedDict(query_job_sig.parameters)
+    del params["max_results"]
+    query_job_sig = query_job_sig.replace(parameters=params.values())
+
+    assert query_job_sig == iterator_sig
